==> 2.6.9.tar.gz: lib/variables.dart <==
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'listener.dart';
import 'dart:developer';

class CoreValues {
  static var uuidThreats = [];
  static var uuidName = {};
  static var nameUUID = {};

  static var uuidGname = {};    //gname with All Global
  static var gnameUUID = {};   //gname with All Global

  static var uuidGthreats =[];  // profile Gthereast
  static var guuidGname = {};   // profile list
  static var gnameguuid = {};   // profile list

  static var flagMainUser = false;

  static Map<String, List<dynamic>> userPositive = {};
  static Map<String, List<dynamic>> userNegative = {};
  static Map<String, List<dynamic>> devicePositive = {};
  static Map<String, List<dynamic>> deviceNegative = {};
  static var userThreatScore = {};
  static var deviceThreatScore = {};

  static Map<String, List<Node>> userRecommendation = {};
  static Map<String, List<Node>> deviceRecommendation = {};
  static Map<String, List<Node>> userImplementedRecommendation = {};
  static Map<String, List<Node>> deviceImplementedRecommendation = {};
  //static var existReco = [];

  static var aggregate = [];
  static var gagg = 0.0;
  static var nagg = 0.0;

  static var dependent = {};
  static var enabler = {};
  static var based = {};

  static var enterpriseNode = {};

  static var impactValues = {'high': 1.0, 'medium': 0.5, 'low': 0.1};

  static var uuidDeviceImplementedRecommendations = []; //저장용
  static var uuidUserImplementedRecommendations = []; //저장용
}

class Storage {
  static StorageController? controller;

  static var userUUID = ''; //only one
  static var deviceUUID = ''; //only one
  static var geigerIndicatorUUID = '1234-1234-1234';
  static var pluginUUIDs = []; //loop
  static var getValuePath = [];



  Future getUUID(var key) async {
      var local = await controller!.get(':Local');
      var temp = await local.getValue(key);

    return temp?.getValue('en');
  }

  Future getPlugUUID() async {
      var plugins;
    try{
      plugins = await controller!.get(':Devices:$deviceUUID}');

    } on StorageException {
        log("'::Devices:$deviceUUID:plugin' doesn't exist in storage'===========");
//        print("Waiting ':Local:plugin'===========");
//        registerListener(Listener.pluginLocal,':Local:plugin');
//
//        try{
//            List<Event> e = await Listener.pluginLocal.getNumEvents(1,5);
//            print("Length of the Event ${e.length}");
//            if (e.length > 0) {
//              getPlugUUID();
//            }
//        }catch(e){
//          print(e);
//        }
     }

    return await plugins.getChildNodesCsv();
  }
}

class Types {
  static const devices = 'Devices';
  static const users = 'Users';
  static const geigerScoreUser = 'GeigerScoreUser';
  static const geigerScoreDevice = 'GeigerScoreDevice';
  static const recommendations = 'recommendations';
  static const geigerScoreAggregate = 'GeigerScoreAggregate';
  static const geigerScoreMSE = 'GeigerScoreMSE';
  static const enterprise = 'Enterprise';

  static const digitallyBased = 'digitally based';
  static const digitalEnabler = 'digitally enabler';
  static const digitallyDependent = 'digitally dependent';
}

class Listener{

//  static LocalStorageListener threatGlobal = LocalStorageListener();
//  static LocalStorageListener profilesGlobal = LocalStorageListener();
//  static LocalStorageListener recoGlobal = LocalStorageListener();
//  static LocalStorageListener pluginLocal = LocalStorageListener();
//  static LocalStorageListener usersEnterprise = LocalStorageListener();
//  static LocalStorageListener devicesEnterprise = LocalStorageListener();
//  static LocalStorageListener enterprise = LocalStorageListener();
  static SensorValueListener sensorsValue = SensorValueListener();
 // static SensorValueListener recommendation = SensorValueListener();

}

==> 2.7.2.tar.gz: lib/variables.dart <==
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'listener.dart';
import 'dart:developer';

class CoreValues {
  static var uuidThreats = [];
  static var uuidName = {};
  static var nameUUID = {};

  static var uuidGname = {};    //gname with All Global
  static var gnameUUID = {};   //gname with All Global

  static var uuidGthreats =[];  // profile Gthereast
  static var guuidGname = {};   // profile list
  static var gnameguuid = {};   // profile list

  static var flagMainUser = false;

  static Map<String, List<dynamic>> userPositive = {};
  static Map<String, List<dynamic>> userNegative = {};
  static Map<String, List<dynamic>> devicePositive = {};
  static Map<String, List<dynamic>> deviceNegative = {};
  static var userThreatScore = {};
  static var deviceThreatScore = {};

  static Map<String, List<Node>> userRecommendation = {};
  static Map<String, List<Node>> deviceRecommendation = {};
  static Map<String, List<double>> userImplementedRecommendation = {};
  static Map<String, List<double>> deviceImplementedRecommendation = {};

  //static var existReco = [];

  static var aggregate = [];
  static var gagg = 0.0;
  static var nagg = 0.0;

  static var dependent = {};
  static var enabler = {};
  static var based = {};

  static var enterpriseNode = {};

  static var impactValues = {'high': 1.0, 'medium': 0.5, 'low': 0.1};

  static var uuidDeviceImplementedRecommendations = []; //저장용
  static var uuidUserImplementedRecommendations = []; //저장용
}

class Storage {
  static StorageController? controller;

  static var userUUID = ''; //only one
  static var deviceUUID = ''; //only one
  static var geigerIndicatorUUID = '1234-1234-1234';
  static var pluginUUIDs = []; //loop
  static var getValuePath = [];



  Future getUUID(var key) async {
      var local = await controller!.get(':Local');
      var temp = await local.getValue(key);

    return temp?.getValue('en');
  }

  Future getPlugUUID() async {
      var plugins;
    try{
      plugins = await controller!.get(':Devices:$deviceUUID}');

    } on StorageException {
        log("'::Devices:$deviceUUID:plugin' doesn't exist in storage'===========");
//        print("Waiting ':Local:plugin'===========");
//        registerListener(Listener.pluginLocal,':Local:plugin');
//
//        try{
//            List<Event> e = await Listener.pluginLocal.getNumEvents(1,5);
//            print("Length of the Event ${e.length}");
//            if (e.length > 0) {
//              getPlugUUID();
//            }
//        }catch(e){
//          print(e);
//        }
     }

    return await plugins.getChildNodesCsv();
  }
}

class Types {
  static const devices = 'Devices';
  static const users = 'Users';
  static const geigerScoreUser = 'GeigerScoreUser';
  static const geigerScoreDevice = 'GeigerScoreDevice';
  static const recommendations = 'recommendations';
  static const geigerScoreAggregate = 'GeigerScoreAggregate';
  static const geigerScoreMSE = 'GeigerScoreMSE';
  static const enterprise = 'Enterprise';

  static const digitallyBased = 'digitally based';
  static const digitalEnabler = 'digitally enabler';
  static const digitallyDependent = 'digitally dependent';
}

class Listener{

//  static LocalStorageListener threatGlobal = LocalStorageListener();
//  static LocalStorageListener profilesGlobal = LocalStorageListener();
//  static LocalStorageListener recoGlobal = LocalStorageListener();
//  static LocalStorageListener pluginLocal = LocalStorageListener();
//  static LocalStorageListener usersEnterprise = LocalStorageListener();
//  static LocalStorageListener devicesEnterprise = LocalStorageListener();
//  static LocalStorageListener enterprise = LocalStorageListener();
  static SensorValueListener sensorsValue = SensorValueListener();
 // static SensorValueListener recommendation = SensorValueListener();

}
